# Menus and the Toolbar

Windows Git provides the following menu items, the most commonly used of which also appear on the toolbar:

Scrollback Ctrl+L
Opens the scrollback dialog, which shows all the text printed since the current game was started.

Fonts/Proportional Font...
Opens the font dialog for selecting the proportional font used for text in the game.

Fonts/Fixed Width Font...
Opens the font dialog for selecting the fixed-width font used for text in the game that needs a particular layout, such as the status bar, or any maps or symbols the game might display.

View/Options...
Opens the options dialog.

Help
Opens this help window.

About This Game
Opens a dialog showing the cover art and description of the game, if available.

About Git
Opens the About dialog, which shows the version number and credits for this version of Windows Git.

Exit Alt+F4
Exits the interpreter.